==> fediz-1.5.1-source-release.zip: fediz-1.5.1/systests/oidc/src/test/java/org/apache/cxf/fediz/systests/oidc/OIDCTomcatTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.fediz.systests.oidc;


import org.junit.AfterClass;
import org.junit.BeforeClass;

/**
 * Some OIDC tests where the OIDC is deployed and secured by the Fediz Tomcat plugin.
 */
public class OIDCTomcatTest extends AbstractOIDCTest {

    private static final String SERVLET_CONTEXT_NAME = "fediz-oidc-tomcat";

    @BeforeClass
    public static void init() throws Exception {
        startServer(SERVLET_CONTEXT_NAME, "fediz_config_tomcat.xml");
    }

    @AfterClass
    public static void cleanup() throws Exception {
        shutdownServer(SERVLET_CONTEXT_NAME);
    }

    @Override
    protected String getServletContextName() {
        return SERVLET_CONTEXT_NAME;
    }

}

==> fediz-1.6.2-source-release.zip: fediz-1.6.2/systests/oidc/src/test/java/org/apache/cxf/fediz/systests/oidc/OIDCTomcatTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.fediz.systests.oidc;


import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.BeforeAll;

/**
 * Some OIDC tests where the OIDC is deployed and secured by the Fediz Tomcat plugin.
 */
public class OIDCTomcatTest extends AbstractOIDCTest {

    private static final String SERVLET_CONTEXT_NAME = "fediz-oidc-tomcat";

    @BeforeAll
    public static void init() throws Exception {
        startServer(SERVLET_CONTEXT_NAME, "fediz_config_tomcat.xml");
    }

    @AfterAll
    public static void cleanup() throws Exception {
        shutdownServer(SERVLET_CONTEXT_NAME);
    }

    @Override
    protected String getServletContextName() {
        return SERVLET_CONTEXT_NAME;
    }

}
